@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdpoly.c,v 1.3 2010/06/24 12:37:15 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdpoly.c,v 1.3 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -55,10 +55,14 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
  */
 
 int
-cifLowX(a, b)
-    CIFPath **a, **b;
+cifLowX(
+    const void *aa,
+    const void *bb)
 {
-    Point *p, *q;
+    const CIFPath **a = (const CIFPath **)aa;
+    const CIFPath **b = (const CIFPath **)bb;
+
+    const Point *p, *q;
 
     p = &(*a)->cifp_point;
     q = &(*b)->cifp_point;
@@ -88,9 +92,12 @@ cifLowX(a, b)
  */
 
 int
-cifLowY(a, b)
-    Point **a, **b;
+cifLowY(
+    const void *aa,
+    const void *bb)
 {
+    const Point **a = (const Point **)aa;
+    const Point **b = (const Point **)bb;
     if ((*a)->p_y < (*b)->p_y)
 	return (-1);
     if ((*a)->p_y > (*b)->p_y)
@@ -119,10 +126,10 @@ cifLowY(a, b)
  */
 
 bool
-cifOrient(edges, nedges, dir)
-    CIFPath *edges[];		/* Array of edges to be categorized. */
-    int dir[];			/* Array to hold directions. */
-    int nedges;			/* Size of arrays. */
+cifOrient(
+    CIFPath *edges[],		/* Array of edges to be categorized. */
+    int nedges,			/* Size of arrays. */
+    int dir[])			/* Array to hold directions. */
 {
     Point *p, *q;
     int n;
@@ -179,10 +186,11 @@ cifOrient(edges, nedges, dir)
  */
 
 bool
-cifCross(edge, dir, ybot, ytop)
-    CIFPath *edge;	/* Pointer to first of 2 path points in edge */
-    int dir;			/* Direction of edge */
-    int ybot, ytop;		/* Range of interest */
+cifCross(
+    CIFPath *edge,	/* Pointer to first of 2 path points in edge */
+    int dir,			/* Direction of edge */
+    int ybot,
+    int ytop)		/* Range of interest */
 {
     int ebot, etop;
 
@@ -223,12 +231,12 @@ cifCross(edge, dir, ybot, ytop)
  */
 
 LinkedRect *
-CIFPolyToRects(path, plane, resultTbl, ui, isCalma)
-    CIFPath *path;		/* Path describing a polygon. */
-    Plane *plane;		/* Plane to draw on */
-    PaintResultType *resultTbl;
-    PaintUndoInfo *ui;
-    bool isCalma;		/* TRUE for Calma, FALSE for CIF */
+CIFPolyToRects(
+    CIFPath *path,		/* Path describing a polygon. */
+    Plane *plane,		/* Plane to draw on */
+    const PaintResultType *resultTbl,
+    PaintUndoInfo *ui,
+    bool isCalma)		/* TRUE for Calma, FALSE for CIF */
 {
     int npts = 0, n, *dir, curr, wrapno;
     int xbot, xtop, ybot, ytop;
