@@ -83,7 +83,7 @@ struct seeTypesArg
  */
 
 int
-DBSrCellPlaneArea(BPlane *plane, Rect *rect, int (*func)(), ClientData arg)
+DBSrCellPlaneArea(BPlane *plane, const Rect *rect, int (*func)(), ClientData arg)
 {
     BPEnum *bpe;
     CellUse *use;
@@ -677,7 +677,7 @@ dbCellLabelSrFunc(scx, fp)
 {
     Label *lab;
     Rect *r = &scx->scx_area;
-    TileTypeBitMask *mask = fp->tf_mask;
+    const TileTypeBitMask *mask = fp->tf_mask;
     CellDef *def = scx->scx_use->cu_def;
     char *tnext;
     int result;
@@ -1525,8 +1525,10 @@ DBScaleEverything(scalen, scaled)
     /* Scale all elements */
     DBWScaleElements(scalen, scaled);
 
+#ifdef ROUTE_MODULE
     /* Recovery of global plane pointers */
     MZAttachHintPlanes();
+#endif
 
     /* Modify root box */
     ToolScaleBox(scalen, scaled);
@@ -1631,7 +1633,10 @@ dbTileScaleFunc(tile, scvals)
     if (IsSplit(tile))
 	type = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
     DBNMPaintPlane(scvals->ptarget, exact, &targetRect,
-		((scvals->doCIF) ? CIFPaintTable :
+		(
+#ifdef CIF_MODULE
+		(scvals->doCIF) ? CIFPaintTable :
+#endif
 		DBStdPaintTbl(type, scvals->pnum)),
 		(PaintUndoInfo *)NULL);
     return 0;
